scout db
Scout transcript database management.
Usage
scout db [OPTIONS] COMMAND [ARGS]...
Options
| Name | Type | Description | Default |
|---|---|---|---|
--help |
boolean | Show this message and exit. |
Subcommands
| index | Create or rebuild the index for a transcript database. |
| schema | Print the transcript database schema. |
| validate | Validate a transcript database schema. |
scout db index
Create or rebuild the index for a transcript database.
This scans all parquet data files and creates a manifest index containing metadata for fast queries. Any existing index files are replaced.
Usage
scout db index [OPTIONS] DATABASE_LOCATION
Options
| Name | Type | Description | Default |
|---|---|---|---|
--help |
boolean | Show this message and exit. |
Subcommands
scout db schema
Print the transcript database schema.
Outputs the schema in various formats for use when creating transcript databases outside of the Python API.
Examples: scout db schema # Avro schema to stdout
scout db schema --format pyarrow # PyArrow schema
scout db schema -o transcript.avsc # Save to file
Usage
scout db schema [OPTIONS]
Options
| Name | Type | Description | Default |
|---|---|---|---|
--format |
choice (avro | pyarrow | json | pandas) |
Output format (default: avro). | avro |
--output, -o |
path | Write to file instead of stdout. | |
--help |
boolean | Show this message and exit. |
Subcommands
scout db validate
Validate a transcript database schema.
Checks that the database has the required fields and correct types.
Examples: scout db validate ./my_transcript_db
Usage
scout db validate [OPTIONS] DATABASE_LOCATION
Options
| Name | Type | Description | Default |
|---|---|---|---|
--help |
boolean | Show this message and exit. |